####################
PyDMTemplateRepeater
####################

.. autoclass:: pydm.widgets.template_repeater.PyDMTemplateRepeater
   :members:
   :show-inheritance:


.. note::
   See `QFrame Documentation <https://doc.qt.io/qtforpython-6.2/PySide6/QtWidgets/QFrame.html>`_ for all inherited properties and methods.